bbprep.PanelBuildingBlock
=========================

.. currentmodule:: bbprep

.. autoclass:: PanelBuildingBlock
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~PanelBuildingBlock.get_bonders
      ~PanelBuildingBlock.get_concave_direction
      ~PanelBuildingBlock.get_long_axis
      ~PanelBuildingBlock.show_long_axis
   
   

   
   
   